clear all
close all
datapath = 'C:\GIS\MigBird\Matlab_mig_bird\';
%% STEP 1: READ LANDSCAPE DATA

%%%%% NODE DATA INFORMATION
% 1:FID; 2:Y-index; 3:X-index; 4:code; 5:long; 6:lat; 7:shoreline; 8: open
% water; 9: ice/snow; 10:open space 11:low-int devel; 12:med-intense
% devel; 13:high-int develop; 14:barren; 15:Decid Forest; 16:Evergreen
% forest; 17:mixed forest; 18:dwarf scrub; 19:Shrub/scrub 20:herb grass;
% 21:sedge/herb; 22:moss; 23:pasture/hay; 24:crops; 25:woody wetlands;
% 26:herb wetlands; 27:mean dist to crops; 28:std to crops; 29:mean woody
% wet; 30:std wood wet; 31:mean herb wet; 32:std herb wet
[NODE_DATA,txt,raw] = xlsread('NA_NODE_LC2.xlsx');
num_nodes = size(NODE_DATA,1);
node_move = 3000;
hab_dist = zeros(num_nodes,3);
num_years = 1;
num_flocks = 1;
num_jumps = 8;

%% INCORPORATE WITHIN NODE DISTANCE EFFECTS
% IF THERE IS NO CROP, WOODY WETLANDS OR HERBACEAUS WETLANDS THEN SETTING
% THE HABITAT VALUE TO ZERO.  OTHERWISE THE NORMCDF WILL BE UNDEFINED
for i = 1:num_nodes
    % crop
    if NODE_DATA(i,24)==0
        hab_dist(i,1) = 0;

    else
        hab_dist(i,1) = normcdf(node_move,NODE_DATA(i,27),max(NODE_DATA(i,28),30));
    end
    
    if NODE_DATA(i,25)==0
        hab_dist(i,2) = 0;

    else
        hab_dist(i,2) = normcdf(node_move,NODE_DATA(i,29),max(NODE_DATA(i,30),30));
    end
    
    if NODE_DATA(i,26)==0
        hab_dist(i,3) = 0;

    else
        hab_dist(i,3) = normcdf(node_move,NODE_DATA(i,31),max(NODE_DATA(i,32),30));
    end
end
coords = NODE_DATA(:,2:3);

bird_hab(:,1) = NODE_DATA(:,7);
bird_hab(:,2:4)=(NODE_DATA(:,24:26).*hab_dist);
bird_hab(:,2) = 0; % crops go to zero kcals for spring migration

cals_temp = sum(bird_hab,2)*33945; 

%% IDENTIFYING START NODES AND INITIAL POPULATION SIZE
% USE DATA ON MALLARD DISTRIBUTION ACCORDING TO USFWS BREEDING POPULATION 
% SURVEY AND NATURE SERVE DISTRIBUTION DATA
clear txt raw
S = shaperead('NorthAmeerica_20mi_grid_wAK_BPOP_NSmallard_join.shp');
temp(:,1) = [S.ID];
temp(:,2) = [S.Y_INDEX];
temp(:,3) = [S.X_INDEX];
temp(:,4) = [S.NORMPOP]; %% BIRDS IN MILLIONS
temp(:,5) = [S.COUNT];
temp(:,6) = [S.Natureserv]; %3=non-breeding only; 2 = Breeding only
c = size(NODE_DATA,2);

bird_start = 1000000*sum([S.NORMPOP].*([S.Natureserv]==2)); % number of birds in beginning

for i = 1:size(NODE_DATA,1)
    BB(i) = find(temp(:,2)==NODE_DATA(i,2)&temp(:,3)==NODE_DATA(i,3));
end


%% NODE definition - use Nature SErve range maps to select nodes
NODE_DATA(:,c+1) = temp(BB,4); % num birds
NODE_DATA(:,c+2) = temp(BB,6); % breeding or non-breeding

AA = find(NODE_DATA(:,c+2)==1 | NODE_DATA(:,c+2)==2 |NODE_DATA(:,c+2)==3);
NODE_DATA = NODE_DATA(AA,:); % NEW SET OF NODES
bird_hab = bird_hab(AA,:);
cals_temp = cals_temp(AA,1); clear AA

% remove really poor nodes to speed up analysis - assume that birds use
% only top 97.5% of the nodes - gets rid of extremely poor nodes only
AA = find(cals_temp > 0.025*max(cals_temp)); % CUT-OFF FOR INCLUDING AS HABITAT TO SIMPLIFY PROBLEM
NODE_DATA = NODE_DATA(AA,:); % NEW SET OF NODES
num_bird_nodes = size(NODE_DATA,1);
cals_temp = cals_temp(AA,1);
bird_hab = bird_hab(AA,:);
clear AA

% IDENTIFY BREEDING AND WINTERING NODES
BPOP_wt = (NODE_DATA(:,c+1).*(NODE_DATA(:,c+2)==2))/sum(NODE_DATA(:,c+1).*(NODE_DATA(:,c+2)==2));
cal_wt = (cals_temp.*(NODE_DATA(:,c+2)==2))/sum(cals_temp.*(NODE_DATA(:,c+2)==2));
cal_winter_wt=(cals_temp.*(NODE_DATA(:,c+2)==3))/sum(cals_temp.*(NODE_DATA(:,c+2)==3));

breed_wt = (BPOP_wt.*cal_wt)/sum(BPOP_wt.*cal_wt);
breed_pop = round(bird_start.*breed_wt);
winter_pop = round(bird_start.*cal_winter_wt);
%
breed = find(NODE_DATA(:,c+2)==2);
breeding_nodes = NODE_DATA(breed,1)';

end_nodes = breeding_nodes;

wint = find(NODE_DATA(:,c+2)==3);
winter_nodes = NODE_DATA(wint,1)';

start_nodes = winter_nodes;
init_birds = winter_pop(wint,1);

%% Parameter scenarios for sensitivity analysis
[param_scenarios,txt,raw] = xlsread('parameter_scenarios.xlsx');
clear txt raw

% c1 param ID; c2 shoreline cals; c3 crop cals; c4 herb wet
% cals; c5 woody wet cals; c6 tank cals; c7 flight cost; c8 flight speed;
% c9 flight fuel efficiency (c8/c7); c10 flight range (c9*c6)


%% START SENSITIVITY ANALYSIS
num_iters = 500;
cals = zeros(num_bird_nodes,num_iters);

BUDS = zeros(num_bird_nodes,num_iters);
for rr = 1:num_iters
    
    for h = 1:4
        cals(:,rr) = cals(:,rr)+bird_hab(:,h)*param_scenarios(rr,h+1);
    end
    
    % Call flyway model sensitivity analysis function
    [NoActionCell] = runflywaymodel_sens(datapath, end_nodes, start_nodes, init_birds, num_flocks, num_jumps,param_scenarios(rr,:),NODE_DATA,cals(:,rr));
    test = zeros(num_bird_nodes,num_jumps);
    test2=test;
    for tt = 1:num_flocks
        test = test+ cell2mat(NoActionCell(tt,2)); %birds surviving
        test2 = test2+ cell2mat(NoActionCell(tt,4));%bird stopover time
        BUDS(:,rr) = BUDS(:,rr)+cell2mat(NoActionCell(tt,3));%bird-use-days
    end
    test2 = test2/num_flocks;

    spring_end(rr,1) = sum(test(breed,num_jumps),1); % number of birds surviving
    spring_time(rr,1) = sum(test(breed,num_jumps).*test2(breed,num_jumps),1)...
        /spring_end(rr,1);% time it takes to make it
    
end
