% function [NoActionCell,ActionCell,final] = runflywaymodelNew_multi_end_3_7_12(action)
function [NoActionCell] = runflywaymodel_sens(datapath, end_nodes, start_node, init_birds, num_flocks, num_jumps,parameters,NODE_DATA,cals)
% datapath = where the files are
% end_nodes = where birds are going
% start_node = where birds are coming from
% init_birds = initial distribution of birds across the landscape
% num_flocks = number of bouts of birds to send

tic

% 
%datapath:  This is the file where the data resides'C:\Users\Eric Lonsdorf\Documents\MATLAB\MigBirdModel\TextFiles\';

% Load KCal data.  C1 contains total KCals available in cell.
% Using NLCD, land cover is converted to KCals for each species.  Sum
% of KCals from all 30 meter squares w/in 20 mile node gives total.
% C2 is adjusted KCals available calculated as roosting x forage - flight cost.
% Forage is determined from land cover.  Roosting is from shoreline
% data and is normalized b/t 0 and 1. Right now, roosting is foraging
% habitat.

% NODE_DATA = load(strcat(datapath,'NODE_US_LC.txt'));
n = size(NODE_DATA,1);% Number of nodes

% All node information is containted here.  Column 1 is node id, C2 is
% x-coordinate, C3 is y-coordinate (albers equal area - meters), C4 is
% total node area; C5 is area of shore, C6 is crop area, c7 is woody
% wetland area, c8 is herbaceous wetland, c9 is proportion of crop within
% 1000m of water, c10 woody w/in 1km of water, c11 herb w/in 1000km of
% water, c12 is amount of developed open space, c13 is low intens, c14 is
% med intensity and c15 is high intens


mtxNode = NODE_DATA(:,1);
mtxNode(:,2:3) = NODE_DATA(:,5:6);



mtxKCal(:,2)=cals(:,1);
mtxKCal(:,1)=cals(:,1);

n_end = size(end_nodes,2);
for j = 1:n_end
    row_end_nodes(1,j) = find(NODE_DATA(:,1)==end_nodes(1,j));
end
mtxEndNode = mtxNode(row_end_nodes,:);

% Proportion of birds in end nodes
flocks = ones(1,num_flocks)/num_flocks;


n_start = size(start_node,2);

% start_birds = init_birds;
start_birds = init_birds/sum(init_birds);
index =1;
for j = 1:n_start
    
    if size(find(NODE_DATA(:,1)==start_node(j)),1)==0
        index = index;
    else
    row_start_node(1,j) = find(NODE_DATA(:,1)==start_node(j));
    index = index+1;
    end
end

flocksize = zeros(size(flocks,2),1);

for i=1:size(flocks,2)
    flocksize(i,1) = round(sum(init_birds/num_flocks));
end

% Call function calc_distance_angle, which calculates the distance between
% all nodes and the angle between all nodes
distance_between = zeros(n); % create a matrix of zeros to hold distance b/t each set of nodes
angle_between = zeros(n);

distance_between = Eucl(mtxNode(:,2:3))/1000; % function that calculates Euclidean distance
distance_between = (distance_between.*(distance_between<1400));

distance_end = Eucl(mtxNode(:,2:3),mtxEndNode(:,2:3));
min_end = min(distance_end,[],2);
min_end_from = min_end*ones(1,n);
min_end_to = min_end_from';
dist_end_rule = (min_end_to<min_end_from);
clear min_end_from min_end_to

distance_prob = zeros(n);
distance_prob_norm= zeros(n);
gamma_x = zeros(n);

flight_parms =parameters(1,7)/parameters(1,8); % flight_cost/flight_speed
tank_max = parameters(1,6);

range_limit = 0.8; % can travel 80% of total
gamma_a = 2; % used to calculate distance prob.

% Calculate distance birds can fly based on starting with a full tank
flight_dist= parameters(1,10);

NoActionCell = cell(size(flocks,2),3);

% Determine probability of going from each node to each node based on gamma
% distribution
gamma_x = ((flight_dist-distance_between).*(distance_between>0));
gamma_b = flight_dist-flight_dist*range_limit;
distance_prob = ((gamma_x.^(gamma_a-1)).*(exp(1).^(-gamma_x/gamma_b))/(gamma_b^gamma_a*gamma(gamma_a)));

%% create matrix filters for each rule 
distance_prob = (distance_prob.*(distance_between~=0));
distance_prob = (distance_prob.*(distance_between <= flight_dist));
distance_prob = distance_prob.*dist_end_rule;
for i =1:n_end
    distance_prob(row_end_nodes(1,i),row_end_nodes(1,i))=1;
end

% To begin normalizing the distances, determine the distance from each node to the end for
% the nodes that are accessible based on flight distance
% for i=1:n
distance_prob_norm=(exp(1).^(-((min(distance_between(:,row_end_nodes)')')*ones(1,n))'/(flight_dist)).*distance_prob);

% If the maximum distance is zero, don't do anything, otherwise rescale
% the distances to be between zero and 1 and subtract the result from 1
prob_range =  max(distance_prob_norm,[],2)*ones(1,n);
distance_prob_norm = (distance_prob_norm./prob_range);

for flck = 1:size(flocks,2)
    sprintf(num2str(flck))
    sprintf(num2str(rem(now,1)*24))
    
    if flck==1
        clear NewCalories InitialNumBirds BUDs;
      
        [NewCalories,InitialNumBirds,BUDs,start_day,leave_day] = simpleMarkovMigrationModel(cals,distance_prob,distance_prob_norm,distance_between,parameters, datapath,end_nodes,start_node,start_birds,flocksize(flck,1),num_jumps, NODE_DATA);
        NoActionCell(flck,1) = {NewCalories};
        NoActionCell(flck,2) = {InitialNumBirds};
        NoActionCell(flck,3) = {BUDs};
         NoActionCell(flck,4) = {leave_day};

    else
        
        clear NewCalories InitialNumBirds BUDs;
        [NewCalories,InitialNumBirds,BUDs,start_day,leave_day] = simpleMarkovMigrationModel(NoActionCell{flck-1,1},distance_prob,distance_prob_norm,distance_between,parameters,datapath,end_nodes,start_node,start_birds,flocksize(flck,1),num_jumps, NODE_DATA);
        
        NoActionCell(flck,1) = {NewCalories};
        NoActionCell(flck,2) = {InitialNumBirds};
        NoActionCell(flck,3) = {BUDs};
        NoActionCell(flck,4) = {leave_day};
    end
end

