function [NewCals,NumBirds,BUDs,start_day,leave_day] = simpleMarkovMigrationModel(cals,distance_prob,distance_prob_norm,distance_between,parameters, datapath,end_nodes,start_node,start_birds,b,num_jumps, NODE_DATA)

% Read in all of the data

% This is the file where the data resides
%datapath = 'C:\Program Files\MATLAB\R2006b\work\TextFiles\';
% datapath = 'C:\Users\SJacobi.LPZ_DOMAIN\Documents\MATLAB\TextFiles\';


% Load attractiveness data into attract.  Attract.txt contains
% attractiveness score for each node (20x20 sq. mile) defined by the
% normalized shoreline and saturating function (0-1 scale). Based on
% percentaage of habitat that is considered shoreline.  Not fixed across
% all species - landscape description. Shoreline = 30 meters from water (any welands).

% NODE_DATA = load(strcat(datapath,'NODE_US_LC.txt'));
% NODE_DATA = load(strcat(datapath,'NODE_JVtest_NLCD.txt'));

n = size(NODE_DATA,1);% Number of nodes
n_end = size(end_nodes,2);
for j = 1:n_end
    
    row_end_nodes(1,j) = find(NODE_DATA(:,1)==end_nodes(j));
end
n_start = size(start_node,2);

for j = 1:n_start
    row_start_node(1,j) = find(NODE_DATA(:,1)==start_node(j));
end
% All node information is containted here.  Column 1 is node id, C2 is
% x-coordinate, C3 is y-coordinate (albers equal area - meters), C4 is
% total node area; C5 is area of shore, C6 is crop area, c7 is woody
% wetland area, c8 is herbaceous wetland, c9 is proportion of crop within
% 1000m of water, c10 woody w/in 1km of water, c11 herb w/in 1000km of
% water, c12 is amount of developed open space, c13 is low intens, c14 is
% med intensity and c15 is high intens


tot_hab = sum(NODE_DATA(:,7:26),2);
percent_shore = NODE_DATA(:,7)./tot_hab; % dabbler roost

attract = (percent_shore - min(percent_shore))/(max(percent_shore)-min(percent_shore));

m = num_jumps; % number of steps
start_day = zeros(n,m);
leave_day = start_day;
leave_day(row_start_node,1)=1;
flight_parms =parameters(1,7)/parameters(1,8); % flight_cost/flight_speed
tank_max = parameters(1,6);
cal_parms = 3; % daily_max/(daily_max-basal_cost)

% RESIDENTIAL AREAS ARE SOURCE OF DISTURBANCE - REDUCE CALORIC GAIN EACH
% DAY
disturb_weights = [0.4 0.6 0.8 1];
disturbance =(NODE_DATA(:,10:13)*disturb_weights')./tot_hab;

DG = 100*ones(n,1).*(1-sum(disturbance,2));

bird_tank = zeros(n,m);
for i = row_start_node
    bird_tank(i,1) = tank_max; % start birds with full tank
end
Total_cals = zeros(n,1);

Number_of_birds = zeros(n,m); %holds number of birds in each cell for each times step

Number_of_birds(row_start_node,1) = start_birds*b;

% Number_of_birds(start_node,1) = b; % put all birds in start cell
Moved_birds = zeros(n);
combined_prob = zeros(n);
cal_attract_vector = zeros(1,n);
cal_attract = zeros(n);
bird_tank_temp=zeros(n,1);

deficit = zeros(n);
avgDeficit = zeros(n,1);
RT = zeros(n,m-1);
DS = zeros(n,m-1);
PS = zeros(n,m-1);




for t=1:m-1
    arrival_mat = zeros(n);
    % add the kcals to prob.
    cals_norm(:,1)=cals(:,1)/max(cals(:,1));
    
    % Determine the probability of going to each node from the current node by
    % multiplying the normalized distance probability by the attractivenss and
    % the distance probability based on the gamma distribution
    cal_attract_vector = (attract.*cals_norm)';
    cal_attract = ones(n,1)*(cal_attract_vector);
    combined_prob =  cal_attract.*distance_prob_norm.*distance_prob;
    
    % Normalize the combined sum by dividing each combined prob by the sum of
    % the row
    combined_sum = sum(combined_prob,2)*ones(1,n);
    combined_prob = combined_prob./combined_sum;
    temp = isnan(combined_prob);
    combined_prob(temp) = 0;
    
    
    % Set the probability of going from the end node to the end node equal to 1
    % (once at the end, stay there).  Make all other probs from that node = 0
    for i = 1:n_end
        node = row_end_nodes(:,i);
        combined_prob(node,:) = 0;
        combined_prob(node,node) = 1;
    end
    
    for i=1:n
        
        Moved_birds(i,:) = Number_of_birds(i,t)*combined_prob(i,:);
        
        arrival_mat(i,:) = Moved_birds(i,:)*(leave_day(i,t)+1);
        
    end
    
    Number_of_birds(:,t+1) = round(combined_prob(:,:)'*Number_of_birds(:,t));
    
    End_birds = Number_of_birds(row_end_nodes,t+1); %holding so that birds at end don't die
    
    % Update bird tanks based on movement probs
    
    deficit = flight_parms*distance_between.*Moved_birds; %%total_deficit
    bird_def = flight_parms*distance_between; %bird_deficit
    
    avgDeficit = (sum(deficit,1)./sum(Moved_birds,1))';
    
    start_day(:,t+1)= (sum(arrival_mat,1)./sum(Moved_birds,1))';
    
    
    
    temp = isnan(avgDeficit);
    avgDeficit(temp) = 0;
    start_day(temp,t+1)= 0;
    clear temp
  
    RT(:,t) = avgDeficit(:,1)./DG(:,1); % RESIDENCE TIME
    cals_needed_per_bird = avgDeficit+RT(:,t)*84; % Basal metabolic rate 3.5 kcals per hour *24 hours
    bird_tank(:,t+1) = tank_max-avgDeficit;
  
    Total_cals(:,1) = Number_of_birds(:,t+1).*(cals_needed_per_bird); % estimated total cals removed
    
    Total_cals(row_end_nodes) = 0; % MAKING SURE NOT TO EVALUATE END POINTS
    
    temp = find(Total_cals(:,1)<=cals(:,1));
    RT(temp,t) = avgDeficit(temp,1)./DG(temp,1);
    
    DS(temp,t) = 1-(-0.000006*(tank_max-avgDeficit(temp,1))+0.009);
    
    cals(temp,1) = cals(temp,1)-Total_cals(temp,1);
  
    PS(temp,t) = DS(temp,t).^RT(temp,t);
    
    Number_of_birds(temp,t+1) = round(PS(temp,t).*Number_of_birds(temp,t+1));
    leave_day(temp,t+1) = (start_day(temp,t+1)+RT(temp,t)); %%arrival date plus residence time
    

    clear temp
    %if too many birds for node, reset number of birds to carrying capacity
    temp = Total_cals(:,1)>cals(:,1);

    if size(temp,1)>0
        
        Number_of_birds(temp,t+1) = cals(temp,1)./(((tank_max-bird_tank(temp,t+1)).*cal_parms));
        
        cals(temp,1) = 0;
        RT(temp,t) = avgDeficit(temp,1)./DG(temp,1);
        DS(temp,t) = 1-(-0.000006*(tank_max-avgDeficit(temp,1))+0.009);
        PS(temp,t) = DS(temp,t).^RT(temp,t);
        Number_of_birds(temp,t+1) = PS(temp,t).*Number_of_birds(temp,t+1);
        leave_day(temp,t+1) = (start_day(temp,t+1)+RT(temp,t)); %%arrival date plus residence time
        
    else
    end
    %% calculate bird daily distribution
    
    clear temp
    Number_of_birds(row_end_nodes,t+1) = round(End_birds);
    
    
    
end

NumBirds = Number_of_birds;
NewCals = cals;
BUDs(:,1) = sum(RT(:,:).*Number_of_birds(:,2:m),2);

